# torchbox

The [torchlib](https://github.com/antsfamily/torchlib) package is deprecated.

You can install and test ``torchbox`` by: ``pip install torchbox``, ``import torchbox as tb``, ``print(tb.__version__)``

Please see [torchbox's documentation](http://iridescent.ink/torchbox) for using details.

